@@ -8,6 +8,10 @@ import time
 import requests
 from Crypto.Cipher import AES
 from pbkdf2 import PBKDF2
+try:
+    from urllib.parse import urlencode
+except:
+    from urllib import urlencode
 
 # Shortcut for creating a KeystokClient with the specified options.
 # The options parameter can be an access token or a dictionary with these keys:
@@ -33,9 +37,10 @@ class KeystokClient:
         if not self.options['api_host'].startswith('http'):
             self.options['api_host'] = 'https://' + self.options['api_host']
         if not self.options.get('auth_host', None):
-            self.options['auth_host'] = 'https://keystok.com/oauth/token'
+            self.options['auth_host'] = 'https://keystok.com'
         if not self.options['auth_host'].startswith('http'):
             self.options['auth_host'] = 'https://' + self.options['auth_host']
+        self.options['auth_host'] += '/oauth/token'
         if not self.options.get('cache_dir', None):
             self.options['cache_dir'] = os.path.join(os.path.expanduser('~'), '.keystok')
         if not self.options.get('verbose', None):
@@ -94,11 +99,11 @@ class KeystokClient:
             pass
 
         # Must refresh to get new access token
-        data = urllib.parse.urlencode({
+        data = urlencode({
             'grant_type': 'refresh_token',
             'refresh_token': refresh_token,
         })
-        response = requests.post(REFRESH_TOKEN_URL, data).json()
+        response = requests.post(self.options['auth_host'], data).json()
         response['expires_at'] = int(time.time()) + response['expires_in']
         with open('%s/access_token' % (self.options['cache_dir']), 'w') as f:
             json.dump(response, f)
